from distutils.core import setup

setup(
  name = 'expletives',
  packages = ['expletives'], 
  version = '0.0.4',
  description = 'A expletives vommitting library.',
  author = 'Liling Tan',
  license = 'Apache License version 2.0',
  url = 'https://github.com/alvations/expletives',
  keywords = ['expletives', 'swear-words', 'bad-words', 'banned-words', 'linguistics' , 'nlp'], 
  classifiers = [],
)
